<html>
    <head>
        {% block head %}
        <title>{% block title %}{{ title }}{% endblock %}</title>
        <script type='text/javascript' src='https://s3.amazonaws.com/mturk-public/externalHIT_v1.js'></script>
        {% endblock head %}
    </head>
    <body>
        {% block question_title %}
        {% endblock %}

        <form name='mturk_form' id='mturk_form' action='{{ action_url }}' method='post'>
            <input type='hidden' value='ASSIGNMENT_ID_NOT_AVAILABLE' name='assignmentId' id='assignmentId' />
            {% block question_content %}
            {% endblock %}
            <input class='btn btn-primary' type='submit' id='submitButton' />
        </form>

        {% block postjavascript %}
        <script language='Javascript'>
            turkSetAssignmentID();
        </script>
        {% endblock %}
    </body>
</html>

